#################################################
Getting Started with the Amazon Braket Python SDK
#################################################

It is easy to get started with Amazon Braket Python SDK. You can get
started using an Amazon Braket notebook instance or using
your own environment.

For more information about Amazon Braket, see the full set of documentation
at https://docs.aws.amazon.com/braket/index.html.

.. toctree::
    :maxdepth: 2

************************************************
Getting started using an Amazon Braket notebook
************************************************

You can use the AWS Console to enable Amazon Braket, 
then create an Amazon Braket notebook instance
and run your first circuit with the Amazon Braket Python SDK:

1. `Enable Amazon Braket <https://docs.aws.amazon.com/braket/latest/developerguide/braket-enable-overview.html>`_.
2. `Create an Amazon Braket notebook instance <https://docs.aws.amazon.com/braket/latest/developerguide/braket-get-started-create-notebook.html>`_.
3. `Run your first circuit using the Amazon Braket Python SDK <https://docs.aws.amazon.com/braket/latest/developerguide/braket-get-started-run-circuit.html>`_.

When you use an Amazon Braket notebook, the Amazon Braket SDK and plugins are
preloaded. 

***********************************
Getting started in your environment
***********************************

You can install the Amazon Braket Python SDK in your environment
after enabling Amazon Braket and configuring the AWS SDK for Python:

1. `Enable Amazon Braket <https://docs.aws.amazon.com/braket/latest/developerguide/braket-enable-overview.html>`_.
2. Configure the AWS SDK for Python (Boto3) using the `Quickstart <https://boto3.amazonaws.com/v1/documentation/api/latest/guide/quickstart.html>`_.
3. `Run your first circuit using the Amazon Braket Python SDK <https://docs.aws.amazon.com/braket/latest/developerguide/braket-get-started-run-circuit.html>`_.
   
